<?php

if (!defined('_PS_VERSION_')) {
    exit;
}
use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

class Payvalida extends PaymentModule
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'payvalida';
        $this->tab = 'payments_gateways';
        $this->version = '1.5.0';
        $this->author = 'Payvalida';
        $this->need_instance = 1;

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Payvalida');
        $this->description = $this->l('Payvalida. Tarjetas débito, tarjetas crédito, efectivo y redes comerciales...tú eliges el medio de pago que prefieras.');

        $this->confirmUninstall = $this->l('Seguro deseas desinstalar el modulo?'); 
    }


    public function install()
    {
        if (extension_loaded('curl') == false)
        {
            $this->_errors[] = $this->l('You have to enable the cURL extension on your server to install this module');
            return false;
        }

        Configuration::updateValue('PAYVALIDA_LIVE_MODE', false);
        return parent::install() &&
            $this->registerHook('header') &&
            $this->registerHook('backOfficeHeader') &&
            $this->registerHook('payment') &&
            $this->registerHook('paymentReturn') &&
            $this->registerHook('actionCartSave') &&
            $this->registerHook('actionOrderDetail') &&
            $this->registerHook('actionOrderStatusUpdate') &&
            $this->registerHook('actionPaymentConfirmation') &&
            $this->registerHook('displayBeforePayment') &&
            $this->registerHook('displayOrderConfirmation') &&
            $this->registerHook('displayPayment') &&
            $this->registerHook('displayPaymentReturn') &&
            $this->registerHook('paymentOptions');
    }

    public function uninstall()
    {
        Configuration::deleteByName('PAYVALIDA_LIVE_MODE');

        return parent::uninstall();
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        /**
         * If values have been submitted in the form, process.
         */
        if (((bool)Tools::isSubmit('submitPayvalidaModule')) == true) {
            $this->postProcess();
        }
        $this->context->smarty->assign('module_dir', $this->_path);
        return $output.$this->renderForm();
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitPayvalidaModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                'title' => $this->l('Payvalida, Configuraciones'),
                'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Modo produccion'),
                        'name' => 'PAYVALIDA_LIVE_MODE',
                        'is_bool' => true,
                        'desc' => $this->l('Activa el modo produccion'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'col' => 3,
                        'name'  => 'MERCHANTID_PV',
                        'type'  => 'text',
                        'desc'  => 'Esta es la identificación proporcionada por Payvalida cuando creas una cuenta',
                        'label' => 'Payvalida merchant id',
                      ),
                      array(
                        'col' => 3,
                        'name'  => 'FIXED_HASH_PV',
                        'label' => 'Payvalida FIXED_HASH',
                        'desc'  => 'Este es el FIXED_HASH proporcionado por Payvalida cuando creas una cuenta.',
                        'type'  => 'text'
                      ),
                      array(
                        'col' => 3,
                        'name'  => 'FIXED_HASH_NOTIFICATION_PV',
                        'label' => 'Payvalida FIXED_HASH_NOTIFICATION',
                        'desc'  => 'Este es el FIXED_HASH_NOTIFICATION proporcionado por Payvalida cuando creas una cuenta.',
                        'type'  => 'text'
                      ),
                      array(
                        'col' => 3,
                        'name'  => 'EXPIRATION_DAYS',
                        'label' => 'Payvalida expiration Days',
                        'desc'  => 'El número de días para vencimiento de las órdenes debe ser un valor entero entre 1 y 30. Si el valor ingresado no se encuentra en este rango, se tomará el valor predeterminado de 1 día',
                        'type'  => 'text'
                      ),
                ),
                'submit' => array(
                    'title' => $this->l('Guardar'),
                ),
            ),
        );
    }

    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(
            'PAYVALIDA_LIVE_MODE' => Configuration::get('PAYVALIDA_LIVE_MODE', false),
            'MERCHANTID_PV' => Configuration::get('MERCHANTID_PV', null),
            'FIXED_HASH_PV' => Configuration::get('FIXED_HASH_PV', null),
            'FIXED_HASH_NOTIFICATION_PV' => Configuration::get('FIXED_HASH_NOTIFICATION_PV', null),
            'EXPIRATION_DAYS' => Configuration::get('EXPIRATION_DAYS', null),
        );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key));
        }
    }

    public function hookPaymentOptions($params)
    {
        
        if (!$this->active) {
            return;
        }

        if (!$this->checkCurrency($params['cart'])) {
            return;
        }
        
        $newOptionPV = new PaymentOption();
        $newOptionPV->setCallToActionText($this->trans('Pagar con Payvalida', array(), 'Modules.Payvalida.Shop'))
            ->setModuleName($this->name)
            ->setAdditionalInformation('Payvalida. Tarjetas débito, tarjetas crédito, efectivo y redes comerciales...tú eliges el medio de pago que prefieras.')
            ->setAction($this->context->link->getModuleLink($this->name, 'redirect', array(), true));
            $payment_optionsPV = [
                $newOptionPV,
            ];

        return $payment_optionsPV;
    }

        /**
     * Show the payment method in the shop cart.
     */
    public function checkCurrency($cart)
	{
		$currency_order = new Currency($cart->id_currency);
		$currencies_module = $this->getCurrency($cart->id_currency);

		if (is_array($currencies_module))
			foreach ($currencies_module as $currency_module)
				if ($currency_order->id == $currency_module['id_currency'])
					return true;
		return false;
    }

        /**
     * return the fixed hash notification, save in the db, from the configuration
     */
    public function get_api_key()
    {
        return Configuration::get('FIXED_HASH_NOTIFICATION_PV');
    }

    public function get_mode()
    {
        return Configuration::get('PAYVALIDA_LIVE_MODE');
    }

    public function get_merchID()
    {
        return Configuration::get('MERCHANTID_PV');
    }

    public function get_fixedH()
    {
        return Configuration::get('FIXED_HASH_PV');
    }

    public function get_expirationDays()
    {
        return Configuration::get('EXPIRATION_DAYS');
    }
}
